print("import: 'copulae'")
import copulae

print("import: 'copulae.archimedean'")
import copulae.archimedean

print("import: 'copulae.copula'")
import copulae.copula

print("import: 'copulae.core'")
import copulae.core

print("import: 'copulae.datasets'")
import copulae.datasets

print("import: 'copulae.elliptical'")
import copulae.elliptical

print("import: 'copulae.empirical'")
import copulae.empirical

print("import: 'copulae.gof'")
import copulae.gof

print("import: 'copulae.indep'")
import copulae.indep

print("import: 'copulae.special'")
import copulae.special

print("import: 'copulae.stats'")
import copulae.stats

print("import: 'copulae.utility'")
import copulae.utility

